pub trait IntoAttributeValue {
// Required method
fn into_attribute_value(self) -> Option<String>;
}Expand description
A trait for types which can be converted to an attribute value.
Required Methods
Sourcefn into_attribute_value(self) -> Option<String>
fn into_attribute_value(self) -> Option<String>
Turns this into an attribute string, or None if it shouldn’t be added.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".